summaryrefslogtreecommitdiffstats
path: root/c++/src/H5AbstractDs.cpp
diff options
context:
space:
mode:
authorBinh-Minh Ribler <bmribler@hdfgroup.org>2004-08-20 04:35:18 (GMT)
committerBinh-Minh Ribler <bmribler@hdfgroup.org>2004-08-20 04:35:18 (GMT)
commit824ba5e2fde476934df42284271c358b14e1a6af (patch)
treecaf62890a1527b0fdc2a77a550c7e11f30c48584 /c++/src/H5AbstractDs.cpp
parentb142a4144862b22c37c27aa11e2ee519a08ede2f (diff)
downloadhdf5-824ba5e2fde476934df42284271c358b14e1a6af.zip
hdf5-824ba5e2fde476934df42284271c358b14e1a6af.tar.gz
hdf5-824ba5e2fde476934df42284271c358b14e1a6af.tar.bz2
[svn-r9129] Purpose: Updating documentation
Description: Updated various function headers for the RM as reviewing progresses. Rearranged functions in header files for more sensible look of the RM. Platforms tested: SunOS 5.7 (arabica) Linux 2.4 (eirene)
Diffstat (limited to 'c++/src/H5AbstractDs.cpp')
-rw-r--r--c++/src/H5AbstractDs.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/c++/src/H5AbstractDs.cpp b/c++/src/H5AbstractDs.cpp
index 79aaadf..33fadc5 100644
--- a/c++/src/H5AbstractDs.cpp
+++ b/c++/src/H5AbstractDs.cpp
@@ -53,16 +53,16 @@ AbstractDs::AbstractDs( const AbstractDs& original ) : H5Object( original ) {}
// Function: AbstractDs::getTypeClass
///\brief Returns the class of the datatype that is used by this
/// object, which can be a dataset or an attribute.
-///\return Datatype class identifier
+///\return Datatype class identifier
///\exception H5::DataTypeIException
// Programmer Binh-Minh Ribler - 2000
//--------------------------------------------------------------------------
H5T_class_t AbstractDs::getTypeClass() const
{
// Gets the datatype used by this dataset or attribute.
// p_getType calls either H5Dget_type or H5Aget_type depending on
// which object invokes getTypeClass
- DataType datatype( p_getType());
+ DataType datatype(p_get_type());
// Gets the class of the datatype and validate it before returning
H5T_class_t type_class = H5Tget_class( datatype.getId());
@@ -79,16 +79,16 @@ H5T_class_t AbstractDs::getTypeClass() const
// Function: AbstractDs::getDataType
///\brief Returns the generic datatype of this abstract dataset, which
/// can be a dataset or an attribute.
-///\return DataType instance
+///\return DataType instance
///\exception H5::DataTypeIException
// Programmer Binh-Minh Ribler - 2000
//--------------------------------------------------------------------------
DataType AbstractDs::getDataType() const
{
// Gets the id of the datatype used by this dataset or attribute.
// p_getType calls either H5Dget_type or H5Aget_type depending on
// which object invokes getTypeClass
- hid_t datatype_id = p_getType(); // returned value is already validated
+ hid_t datatype_id = p_get_type(); // returned value is already validated
// Create and return the DataType object
DataType datatype( datatype_id );
@@ -99,70 +99,70 @@ DataType AbstractDs::getDataType() const
// Function: AbstractDs::getEnumType
///\brief Returns the enumeration datatype of this abstract dataset which
/// can be a dataset or an attribute.
-///\return EnumType instance
+///\return EnumType instance
///\exception H5::DataTypeIException
// Programmer Binh-Minh Ribler - 2000
//--------------------------------------------------------------------------
EnumType AbstractDs::getEnumType() const
{
- EnumType enumtype( p_getType());
- return( enumtype );
+ EnumType enumtype(p_get_type());
+ return(enumtype);
}
//--------------------------------------------------------------------------
// Function: AbstractDs::getCompType
///\brief Returns the compound datatype of this abstract dataset which
/// can be a dataset or an attribute.
-///\return CompType instance
+///\return CompType instance
///\exception H5::DataTypeIException
// Programmer Binh-Minh Ribler - 2000
//--------------------------------------------------------------------------
CompType AbstractDs::getCompType() const
{
- CompType comptype( p_getType());
- return( comptype );
+ CompType comptype(p_get_type());
+ return(comptype);
}
//--------------------------------------------------------------------------
// Function: AbstractDs::getIntType
///\brief Returns the integer datatype of this abstract dataset which
/// can be a dataset or an attribute.
-///\return IntType instance
+///\return IntType instance
///\exception H5::DataTypeIException
// Programmer Binh-Minh Ribler - 2000
//--------------------------------------------------------------------------
IntType AbstractDs::getIntType() const
{
- IntType inttype( p_getType());
- return( inttype );
+ IntType inttype(p_get_type());
+ return(inttype);
}
//--------------------------------------------------------------------------
// Function: AbstractDs::getFloatType
///\brief Returns the floating-point datatype of this abstract dataset,
/// which can be a dataset or an attribute.
-///\return FloatType instance
+///\return FloatType instance
///\exception H5::DataTypeIException
// Programmer Binh-Minh Ribler - 2000
//--------------------------------------------------------------------------
FloatType AbstractDs::getFloatType() const
{
- FloatType floatype( p_getType());
- return( floatype );
+ FloatType floatype(p_get_type());
+ return(floatype);
}
//--------------------------------------------------------------------------
// Function: AbstractDs::getStrType
///\brief Returns the string datatype of this abstract dataset which
/// can be a dataset or an attribute.
-///\return StrType instance
+///\return StrType instance
///\exception H5::DataTypeIException
// Programmer Binh-Minh Ribler - 2000
//--------------------------------------------------------------------------
StrType AbstractDs::getStrType() const
{
- StrType strtype( p_getType());
- return( strtype );
+ StrType strtype(p_get_type());
+ return(strtype);
}
//--------------------------------------------------------------------------
@@ -53,16 +53,16 @@ AbstractDs::AbstractDs( const AbstractDs& original ) : H5Object( original ) {}
{
// Gets the datatype used by this dataset or attribute.
- // p_getType calls either H5Dget_type or H5Aget_type depending on
+ // p_get_type calls either H5Dget_type or H5Aget_type depending on
// which object invokes getTypeClass
@@ -79,16 +79,16 @@ H5T_class_t AbstractDs::getTypeClass() const
{
// Gets the id of the datatype used by this dataset or attribute.
- // p_getType calls either H5Dget_type or H5Aget_type depending on
+ // p_get_type calls either H5Dget_type or H5Aget_type depending on
// which object invokes getTypeClass